@@ -4,12 +4,11 @@ from io import BytesIO
 from typing import Any, Dict
 from urllib.parse import quote_plus
 
-from chocs.http_headers import HttpHeaders
-from chocs.http_query_string import HttpQueryString
-from chocs.http_request import HttpRequest
-from chocs.http_response import HttpResponse
-from chocs.http_status import HttpStatus
-
+from chocs.http.http_headers import HttpHeaders
+from chocs.http.http_query_string import HttpQueryString
+from chocs.http.http_request import HttpRequest
+from chocs.http.http_response import HttpResponse
+from chocs.http.http_status import HttpStatus
 from .serverless import ServerlessFunction
 
 TEXT_MIME_TYPES = [
